@@ -2,7 +2,7 @@
  * reportinterface.cpp
  * SPDX-FileCopyrightText: 2009, 2010, 2011 Dario Andres Rodriguez <andresbajotierra@gmail.com>
  * SPDX-FileCopyrightText: 2009 George Kiagiadakis <gkiagia@users.sourceforge.net>
- * SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
+ * SPDX-FileCopyrightText: 2021-2022 Harald Sitter <sitter@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -12,7 +12,6 @@
 
 #include <KLocalizedString>
 
-#include "applicationdetailsexamples.h"
 #include "backtracegenerator.h"
 #include "bugzillalib.h"
 #include "config-drkonqi.h"
@@ -26,7 +25,7 @@
 // Max size a report may have. This is enforced in bugzilla, hardcoded, and
 // cannot be queried through the API, so handle this client-side in a hardcoded
 // fashion as well.
-static int s_maxReportSize = 65535;
+static const int s_maxReportSize = 65535;
 
 ReportInterface::ReportInterface(QObject *parent)
     : QObject(parent)
@@ -36,8 +35,6 @@ ReportInterface::ReportInterface(QObject *parent)
 
     m_productMapping = new ProductMapping(DrKonqi::crashedApplication(), m_bugzillaManager, this);
 
-    m_appDetailsExamples = new ApplicationDetailsExamples(this);
-
     // Information the user can provide about the crash
     m_userRememberCrashSituation = false;
     m_reproducible = ReproducibleUnsure;
@@ -94,6 +91,7 @@ QString ReportInterface::backtrace() const
 void ReportInterface::setBacktrace(const QString &backtrace)
 {
     m_backtrace = backtrace;
+    Q_EMIT backtraceChanged();
 }
 
 QStringList ReportInterface::firstBacktraceFunctions() const
@@ -114,11 +112,13 @@ QString ReportInterface::title() const
 void ReportInterface::setTitle(const QString &text)
 {
     m_reportTitle = text;
+    Q_EMIT titleChanged();
 }
 
 void ReportInterface::setDetailText(const QString &text)
 {
     m_reportDetailText = text;
+    Q_EMIT detailTextChanged();
 }
 
 void ReportInterface::setPossibleDuplicates(const QStringList &list)
@@ -443,6 +443,7 @@ void ReportInterface::setAttachToBugNumber(uint bugNumber)
 {
     // If bugNumber>0, the report is going to be attached to bugNumber
     m_attachToBugNumber = bugNumber;
+    Q_EMIT attachToBugNumberChanged();
 }
 
 uint ReportInterface::attachToBugNumber() const
@@ -453,6 +454,7 @@ uint ReportInterface::attachToBugNumber() const
 void ReportInterface::setDuplicateId(uint duplicate)
 {
     m_duplicate = duplicate;
+    Q_EMIT duplicateIdChanged();
 }
 
 uint ReportInterface::duplicateId() const
@@ -470,11 +472,6 @@ BugzillaManager *ReportInterface::bugzillaManager() const
     return m_bugzillaManager;
 }
 
-ApplicationDetailsExamples *ReportInterface::appDetailsExamples() const
-{
-    return m_appDetailsExamples;
-}
-
 ProductMapping *ReportInterface::productMapping() const
 {
     return m_productMapping;
